pub enum CryptoError {
InvalidPrivateKeyLength(usize),
InvalidSignature,
InvalidSignatureLength(usize),
InvalidMessageLength(usize),
InvalidPublicKey,
HexDecode(FromHexError),
NonCanonicalMessage {
index: usize,
value: u64,
},
}Expand description
Errors that can occur during cryptographic operations.
Variants
InvalidPrivateKeyLength(usize)
The private key has an invalid length.
InvalidSignature
The signature format is invalid.
InvalidSignatureLength(usize)
The signature has an invalid length.
InvalidMessageLength(usize)
The message has an invalid length.
InvalidPublicKey
The public key is invalid or cannot be decoded.
HexDecode(FromHexError)
Hex decoding failed.
NonCanonicalMessage
A message 8-byte chunk represents a value ≥ the Goldilocks field modulus. Messages must be formed from canonical Goldilocks field elements (each 8-byte little-endian chunk must be in [0, 2¶⁴ − 2³² + 1)).